# -*- coding: utf-8 -*-
"""
@File    : company_config.py
@Date    : 2023-07-18
"""
# 公司资料
company_key_map = [
    # 基本资料
    {
        "title": "公司名称",
        "key": "ORG_NAME",
    },
    {
        "title": "英文名称",
        "key": "ORG_NAME_EN",
    },
    {
        "title": "A股代码",
        "key": "STR_CODEA",
    },

    {
        "title": "A股简称",
        "key": "STR_NAMEA",
    },

    {
        "title": "A股扩位简称",
        "key": "EXPAND_NAME_ABBR",
    },
    {
        "title": "曾用名",
        "key": "FORMERNAME",
    },

    {
        "title": "B股代码",
        "key": "STR_CODEB",
    },

    {
        "title": "B股简称",
        "key": "STR_NAMEB",
    },

    {
        "title": "H股代码",
        "key": "STR_CODEH",
    },

    {
        "title": "H股简称",
        "key": "STR_NAMEH",
    },

    {
        "title": "证券类别",
        "key": "SECURITY_TYPE",
    },
    {
        "title": "上市交易所",
        "key": "TRADE_MARKET",
    },
    {
        "title": "所属东财行业",
        "key": "EM2016",
    },
    {
        "title": "所属证监会行业",
        "key": "INDEDIRECTORS",
    },
    {
        "title": "总经理",
        "key": "PRESIDENT",
    },
    {
        "title": "法人代表",
        "key": "LEGAL_PERSON",
    },
    {
        "title": "董秘",
        "key": "SECRETARY",
    },
    {
        "title": "董事长",
        "key": "CHAIRMAN",
    },

    {
        "title": "证券事务代表",
        "key": "SECPRESENT",
    },
    {
        "title": "独立董事",
        "key": "INDEDIRECTORS",
    },

    {
        "title": "联系电话",
        "key": "ORG_TEL",
    },
    {
        "title": "电子信箱",
        "key": "ORG_EMAIL",
    },
    {
        "title": "传真",
        "key": "ORG_FAX",
    },
    {

        "title": "公司网址",
        "key": "ORG_WEB",
    },

    {
        "title": "办公地址",
        "key": "ADDRESS",
    },

    {
        "title": "注册地址",
        "key": "REG_ADDRESS",
    },
    {
        "title": "区域",
        "key": "PROVINCE",
    },
    {
        "title": "邮政编码",
        "key": "ADDRESS_POSTCODE",
    },
    {
        "title": "注册资本(元)",
        "key": "REG_CAPITAL",
    },
    {
        "title": "工商登记",
        "key": "REG_NUM",
    },
    {
        "title": "雇员人数",
        "key": "EMP_NUM",
    },
    {
        "title": "管理人员人数",
        "key": "TATOLNUMBER",
    },
    {
        "title": "律师事务所",
        "key": "LAW_FIRM",
    },
    {
        "title": "会计师事务所",
        "key": "ACCOUNTFIRM_NAME",
    },
    {
        "title": "公司介绍",
        "key": "ORG_PROFILE",
    },
    {
        "title": "经营范围",
        "key": "BUSINESS_SCOPE",
    },

    # 发行相关
    {
        "title": "成立日期",
        "key": "FOUND_DATE",
    },
    {
        "title": "上市日期",
        "key": "LISTING_DATE",
    },
    {
        "title": "发行市盈率(倍)",
        "key": "AFTER_ISSUE_PE",
    },
    {
        "title": "网上发行日期",
        "key": "ONLINE_ISSUE_DATE",
    },
    {
        "title": "发行方式",
        "key": "ISSUE_WAY",
    },
    {
        "title": "每股面值(元)",
        "key": "PAR_VALUE",
    },
    {
        "title": "发行量(股)",
        "key": "TOTAL_ISSUE_NUM",
    },
    {
        "title": "每股发行价(元)",
        "key": "ISSUE_PRICE",
    },
    {
        "title": "发行费用(元)",
        "key": "DEC_SUMISSUEFEE",
    },
    {
        "title": "发行总市值(元)",
        "key": "TOTAL_FUNDS",
    },
    {
        "title": "募集资金净额(元)",
        "key": "NET_RAISE_FUNDS",
    },
    {
        "title": "首日开盘价(元)",
        "key": "OPEN_PRICE",
    },
    {
        "title": "首日收盘价(元)",
        "key": "CLOSE_PRICE",
    },
    {
        "title": "首日换手率",
        "key": "TURNOVERRATE",
    },
    {
        "title": "首日最高价(元)",
        "key": "HIGH_PRICE",
    },
    {
        "title": "网下配售中签率",
        "key": "OFFLINE_VAP_RATIO",
    },
    {
        "title": "定价中签率",
        "key": "ONLINE_ISSUE_LWR",
    },

]
