# -*- coding: utf-8 -*-
"""
@File    : kcb_stock_config.py
@Date    : 2023-07-17
中国概念股相关接口
"""

list_key_map = [
    {
        "title": "代码",
        "key": "f12",
        "name": "Code"
    },
    {
        "title": "名称",
        "key": "f14",
        "name": "Name"
    },
    {
        "title": "最新价",
        "key": "f2",
        "name": "Close"
    },
    {
        "title": "涨跌幅",
        "key": "f3",
        "name": "ChangePercent"
    },
    {
        "title": "涨跌额",
        "key": "f4",
        "name": "Change"
    },
    {
        "title": "成交量(手)",
        "key": "f5",
        "name": "Volume"
    },
    {
        "title": "成交额",
        "key": "f6",
        "name": "Amount"
    },
    {
        "title": "振幅",
        "key": "f7",
        "name": "Amplitude"
    },
    {
        "title": "最高",
        "key": "f15",
        "name": "Hign"
    },
    {
        "title": "最低",
        "key": "f16",
        "name": "Low"
    },
    {
        "title": "今开",
        "key": "f17",
        "name": "Open"
    },
    {
        "title": "昨收",
        "key": "f18",
        "name": "PreviousClose"
    },
    {
        "title": "量比",
        "key": "f10",
        "name": "VolumeRate"
    },
    {
        "title": "换手率",
        "key": "f8",
        "name": "TurnoverRate"
    },
    {
        "title": "市盈率(动态)",
        "key": "f9",
        "name": "PERation"
    },
    {
        "title": "市净率",
        "key": "f23",
        "name": "PB"
    },
    {
        "title": "总市值",
        "key": "f20"
    },
    {
        "title": "流通市值",
        "key": "f21"
    },
    {
        "title": "60日涨跌幅",
        "key": "f24"
    },
    {
        "title": "年初至今涨跌幅",
        "key": "f25"
    },
    {
        "title": "涨速",
        "key": "f22"
    },
    {
        "title": "5分钟涨跌",
        "key": "f11"
    }
]
