# -*- coding: utf-8 -*-
"""
@File    : hk_stocks_config.py
@Date    : 2023-07-17
"""

list_key_map = [
    {
        "title": "代码",
        "key": "f12",
        "name": "Code"
    },
    {
        "title": "名称",
        "key": "f14",
        "name": "Name"
    },

    {
        "title": "最新价",
        "key": "f2",
        "name": "Close"
    },
    {
        "title": "涨跌额",
        "key": "f4",
        "name": "Change"
    },
    {
        "title": "涨跌幅",
        "key": "f3",
        "name": "ChangePercent"
    },
    {
        "title": "成交量",
        "key": "f5",
        "name": "Volume"
    },
    {
        "title": "成交额",
        "key": "f6",
        "name": "Amount"
    },
    {
        "title": "昨收",
        "key": "f18",
        "name": "PreviousClose"
    },
    {
        "title": "今开",
        "key": "f17",
        "name": "Open"
    },
    {
        "title": "最高",
        "key": "f15",
        "name": "Hign"
    },
    {
        "title": "最低",
        "key": "f16",
        "name": "Low"
    },
    {
        "title": "委比",
        "key": "f33",
        "name": "weibi"
    },
]
