# -*- coding: utf-8 -*-
"""
@File    : ua_util.py
@Date    : 2023-07-17
"""

User_Agent = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/114.0.0.0 Safari/537.36'